@@ -6,10 +6,9 @@ no warnings qw(void once uninitialized numeric);
 package Moops::Keyword::Class;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.031';
+our $VERSION   = '0.032';
 
 use Moo;
-use Devel::GlobalDestruction;
 use B 'perlstring';
 extends qw( Moops::Keyword::Role );
 
@@ -20,13 +19,6 @@ my %using = (
 	Tiny  => 'use Class::Tiny; use Class::Tiny::Antlers;',
 );
 
-sub Moops::Keyword::Class::__GUARD__::DESTROY
-{
-	my $pkg = $_[0][0];
-	$pkg->meta->make_immutable
-		unless in_global_destruction;
-}
-
 sub generate_package_setup_oo
 {
 	my $self  = shift;
@@ -42,25 +34,32 @@ sub generate_package_setup_oo
 	push @lines, "use MooseX::MungeHas qw(@{[ $self->arguments_for_moosex_mungehas ]});"
 		if $using =~ /^Mo/;
 
-	if ($using eq 'Moose' or $using eq 'Mouse')
-	{
-		push @lines, sprintf(
-			'my $__GUARD__%d = bless([__PACKAGE__], "Moops::Keyword::Class::__GUARD__");',
-			100_000 + int(rand 899_000),
-		);
-	}
-	
 	if ($using eq 'Moose')
 	{
 		state $has_xs = !!eval('require MooseX::XSAccessor');
 		push @lines, 'use MooseX::XSAccessor;' if $has_xs;
 	}
 
-	return (
+	my @return = (
 		$using{$using},
 		$self->generate_package_setup_relationships,
 		@lines,
 	);
+	
+	# Note that generate_package_setup_relationships typically adds
+	# `with` statements for composing roles, so we need to add this
+	# make_immutable *after* calling it.
+	$self->_mk_guard('__PACKAGE__->meta->make_immutable;')
+		if $self->should_make_immutable;
+	
+	return @return;
+}
+
+sub should_make_immutable
+{
+	my $self  = shift;
+	my $using = $self->relations->{using}[0] // $self->default_oo_implementation;
+	($using eq 'Moose' or $using eq 'Mouse');
 }
 
 around generate_package_setup_relationships => sub
